@@ -37,14 +37,22 @@
 #define SERVER_USERNAME "tester"
 #define SERVER_PASSWORD "somepass"
 
+#if defined __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wkeyword-macro"
+#endif
 #define private public
 #define protected public
+#if defined __clang__
+#pragma clang diagnostic pop
+#endif
+
+#include <libcmis/document.hxx>
+#include <libcmis/session-factory.hxx>
 
 #include <mockup-config.h>
 #include "test-helpers.hxx"
 #include "atom-session.hxx"
-#include "session-factory.hxx"
-#include "document.hxx"
 
 using namespace std;
 using libcmis::PropertyPtrMap;
