@@ -31,7 +31,14 @@
 #include <cppunit/TestAssert.h>
 #include <cppunit/ui/text/TestRunner.h>
 
+#if defined __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wkeyword-macro"
+#endif
 #define private public
+#if defined __clang__
+#pragma clang diagnostic pop
+#endif
 
 #include "ws-relatedmultipart.hxx"
 #include "ws-requests.hxx"
@@ -120,7 +127,7 @@ class TestFaultDetail : public SoapFaultDetail
         TestFaultDetail( ) : SoapFaultDetail( ) { };
 
     public:
-        ~TestFaultDetail( ) throw ( ) { };
+        ~TestFaultDetail( ) noexcept { };
 
         static SoapFaultDetailPtr create( xmlNodePtr )
         {
